==> robovm-cocoatouch-1.8.0-sources.jar: org/robovm/apple/uikit/UIPickerViewAccessibilityDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPickerViewAccessibilityDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UIPickerViewDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements UIPickerViewAccessibilityDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("pickerView:accessibilityLabelForComponent:")
    public String getAccessibilityLabel(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    @NotImplemented("pickerView:accessibilityHintForComponent:")
    public String getAccessibilityHint(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /*</methods>*/
}

==> robovm-cocoatouch-2.3.18-sources.jar: org/robovm/apple/uikit/UIPickerViewAccessibilityDelegateAdapter.java <==
/*
 * Copyright (C) 2013-2015 RoboVM AB
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.robovm.apple.uikit;

/*<imports>*/
import java.io.*;
import java.nio.*;
import java.util.*;
import org.robovm.objc.*;
import org.robovm.objc.annotation.*;
import org.robovm.objc.block.*;
import org.robovm.rt.*;
import org.robovm.rt.annotation.*;
import org.robovm.rt.bro.*;
import org.robovm.rt.bro.annotation.*;
import org.robovm.rt.bro.ptr.*;
import org.robovm.apple.foundation.*;
import org.robovm.apple.coreanimation.*;
import org.robovm.apple.coregraphics.*;
import org.robovm.apple.coredata.*;
import org.robovm.apple.coreimage.*;
import org.robovm.apple.coretext.*;
import org.robovm.apple.corelocation.*;
import org.robovm.apple.cloudkit.*;
import org.robovm.apple.fileprovider.*;
import org.robovm.apple.intents.*;
import org.robovm.apple.usernotifications.*;
import org.robovm.apple.linkpresentation.*;
/*</imports>*/

/*<javadoc>*/
/*</javadoc>*/
/*<annotations>*//*</annotations>*/
/*<visibility>*/public/*</visibility>*/ class /*<name>*/UIPickerViewAccessibilityDelegateAdapter/*</name>*/ 
    extends /*<extends>*/UIPickerViewDelegateAdapter/*</extends>*/ 
    /*<implements>*/implements UIPickerViewAccessibilityDelegate/*</implements>*/ {

    /*<ptr>*/
    /*</ptr>*/
    /*<bind>*/
    /*</bind>*/
    /*<constants>*//*</constants>*/
    /*<constructors>*//*</constructors>*/
    /*<properties>*/
    
    /*</properties>*/
    /*<members>*//*</members>*/
    /*<methods>*/
    @NotImplemented("pickerView:accessibilityLabelForComponent:")
    public String getAccessibilityLabel(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    @NotImplemented("pickerView:accessibilityHintForComponent:")
    public String getAccessibilityHint(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /**
     * @since Available in iOS 13.0 and later.
     */
    @NotImplemented("pickerView:accessibilityUserInputLabelsForComponent:")
    public NSArray<NSString> getAccessibilityUserInputLabels(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /**
     * @since Available in iOS 11.0 and later.
     */
    @NotImplemented("pickerView:accessibilityAttributedLabelForComponent:")
    public NSAttributedString getAccessibilityAttributedLabel(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /**
     * @since Available in iOS 11.0 and later.
     */
    @NotImplemented("pickerView:accessibilityAttributedHintForComponent:")
    public NSAttributedString getAccessibilityAttributedHint(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /**
     * @since Available in iOS 13.0 and later.
     */
    @NotImplemented("pickerView:accessibilityAttributedUserInputLabelsForComponent:")
    public NSArray<NSAttributedString> getAccessibilityAttributedUserInputLabels(UIPickerView pickerView, @MachineSizedSInt long component) { return null; }
    /*</methods>*/
}
